
########################
# coef for din object
coef.din <-
function (object, ...) {
	cof <- object$coef
    cof
}

########################
# coef for gdina object
coef.gdina <-
function (object, ...) {
	cof <- object$coef
    cof
}

########################
# coef for gdm object
coef.gdm <-
function (object, ...) {
	cof <- object$item
    cof
}


########################
# coef for mcdina object
coef.mcdina <-
function (object, ...) {
	cof <- object$item
    cof
}

########################
# coef for slca object
coef.slca <-
function (object, ...) {
	cof <- object$Xlambda
    cof
}